==> haskell-singletons2.7-2.7-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-singletons2.7.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 singletons
version:              2.7
visibility:           public
id:                   singletons-2.7-9Im0uh7AxZq3U3kvmujUpj
key:                  singletons-2.7-9Im0uh7AxZq3U3kvmujUpj
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:
    Richard Eisenberg <rae@cs.brynmawr.edu>, Jan Stolarek <jan.stolarek@p.lodz.pl>

stability:            experimental
homepage:             http://www.github.com/goldfirere/singletons
synopsis:             A framework for generating singleton types
description:
    This library generates singleton types, promoted functions, and singleton
    functions using Template Haskell. It is useful for programmers who wish
    to use dependently typed programming techniques. The library was originally
    presented in /Dependently Typed Programming with Singletons/, published
    at the Haskell Symposium, 2012.
    (<https://cs.brynmawr.edu/~rae/papers/2012/singletons/paper.pdf>)

    Version 1.0 and onwards works a lot harder to promote functions. See the
    paper published at Haskell Symposium, 2014:
    <https://cs.brynmawr.edu/~rae/papers/2014/promotion/promotion.pdf>.

category:             Dependent Types
abi:                  167264329379ea04bcda63e27a2e8ce9
exposed:              True
exposed-modules:
    Data.Singletons Data.Singletons.CustomStar Data.Singletons.Decide
    Data.Singletons.Prelude Data.Singletons.Prelude.Applicative
    Data.Singletons.Prelude.Base Data.Singletons.Prelude.Bool
    Data.Singletons.Prelude.Const Data.Singletons.Prelude.Either
    Data.Singletons.Prelude.Enum Data.Singletons.Prelude.Eq
    Data.Singletons.Prelude.Foldable Data.Singletons.Prelude.Function
    Data.Singletons.Prelude.Functor Data.Singletons.Prelude.Identity
    Data.Singletons.Prelude.IsString Data.Singletons.Prelude.List
    Data.Singletons.Prelude.List.NonEmpty Data.Singletons.Prelude.Maybe
    Data.Singletons.Prelude.Monad Data.Singletons.Prelude.Monad.Fail
    Data.Singletons.Prelude.Monad.Zip Data.Singletons.Prelude.Monoid
    Data.Singletons.Prelude.Num Data.Singletons.Prelude.Ord
    Data.Singletons.Prelude.Proxy Data.Singletons.Prelude.Semigroup
    Data.Singletons.Prelude.Show Data.Singletons.Prelude.Traversable
    Data.Singletons.Prelude.Tuple Data.Singletons.Prelude.Void
    Data.Singletons.ShowSing Data.Singletons.Sigma
    Data.Singletons.SuppressUnusedWarnings Data.Singletons.TH
    Data.Singletons.TH.Options Data.Singletons.TypeError
    Data.Singletons.TypeLits Data.Singletons.TypeRepTYPE

hidden-modules:
    Data.Singletons.Deriving.Infer Data.Singletons.Deriving.Bounded
    Data.Singletons.Deriving.Enum Data.Singletons.Deriving.Foldable
    Data.Singletons.Deriving.Functor Data.Singletons.Deriving.Ord
    Data.Singletons.Deriving.Show Data.Singletons.Deriving.Traversable
    Data.Singletons.Deriving.Util Data.Singletons.Internal
    Data.Singletons.Prelude.List.Internal
    Data.Singletons.Prelude.List.Internal.Disambiguation
    Data.Singletons.Prelude.Monad.Internal
    Data.Singletons.Prelude.Ord.Disambiguation
    Data.Singletons.Prelude.Semigroup.Internal
    Data.Singletons.Prelude.Semigroup.Internal.Disambiguation
    Data.Singletons.Promote Data.Singletons.Promote.Monad
    Data.Singletons.Promote.Eq Data.Singletons.Promote.Type
    Data.Singletons.Promote.Defun Data.Singletons.Util
    Data.Singletons.Partition Data.Singletons.Prelude.Instances
    Data.Singletons.Names Data.Singletons.Single.Monad
    Data.Singletons.Single.Type Data.Singletons.Single.Eq
    Data.Singletons.Single.Data Data.Singletons.Single.Defun
    Data.Singletons.Single.Fixity Data.Singletons.Single
    Data.Singletons.TypeLits.Internal Data.Singletons.Syntax

import-dirs:          /usr/lib/ghc-8.10.4/site-local/singletons-2.7
library-dirs:         /usr/lib/ghc-8.10.4/site-local/singletons-2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/singletons-2.7
hs-libraries:         HSsingletons-2.7-9Im0uh7AxZq3U3kvmujUpj
depends:
    base-4.14.1.0 containers-0.6.2.1 ghc-boot-th-8.10.4 mtl-2.2.2
    pretty-1.1.3.6 syb-0.7.2.1-LyGaJy3DdjiCurYoAQNPTw
    template-haskell-2.16.0.0 text-1.2.4.1
    th-desugar-1.11-3Q0teavNDtvKDC3GKFcwzn transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-singletons2.7/html/singletons.haddock

haddock-html:         /usr/share/doc/haskell-singletons2.7/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-singletons2.7-2.7-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-singletons2.7.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 singletons
version:              2.7
visibility:           public
id:                   singletons-2.7-KCTTIVBc6a7KNWaKwOeQIZ
key:                  singletons-2.7-KCTTIVBc6a7KNWaKwOeQIZ
license:              BSD-3-Clause
maintainer:           Ryan Scott <ryan.gl.scott@gmail.com>
author:
    Richard Eisenberg <rae@cs.brynmawr.edu>, Jan Stolarek <jan.stolarek@p.lodz.pl>

stability:            experimental
homepage:             http://www.github.com/goldfirere/singletons
synopsis:             A framework for generating singleton types
description:
    This library generates singleton types, promoted functions, and singleton
    functions using Template Haskell. It is useful for programmers who wish
    to use dependently typed programming techniques. The library was originally
    presented in /Dependently Typed Programming with Singletons/, published
    at the Haskell Symposium, 2012.
    (<https://cs.brynmawr.edu/~rae/papers/2012/singletons/paper.pdf>)

    Version 1.0 and onwards works a lot harder to promote functions. See the
    paper published at Haskell Symposium, 2014:
    <https://cs.brynmawr.edu/~rae/papers/2014/promotion/promotion.pdf>.

category:             Dependent Types
abi:                  d1570653bf465fd315d5c13746300945
exposed:              True
exposed-modules:
    Data.Singletons Data.Singletons.CustomStar Data.Singletons.Decide
    Data.Singletons.Prelude Data.Singletons.Prelude.Applicative
    Data.Singletons.Prelude.Base Data.Singletons.Prelude.Bool
    Data.Singletons.Prelude.Const Data.Singletons.Prelude.Either
    Data.Singletons.Prelude.Enum Data.Singletons.Prelude.Eq
    Data.Singletons.Prelude.Foldable Data.Singletons.Prelude.Function
    Data.Singletons.Prelude.Functor Data.Singletons.Prelude.Identity
    Data.Singletons.Prelude.IsString Data.Singletons.Prelude.List
    Data.Singletons.Prelude.List.NonEmpty Data.Singletons.Prelude.Maybe
    Data.Singletons.Prelude.Monad Data.Singletons.Prelude.Monad.Fail
    Data.Singletons.Prelude.Monad.Zip Data.Singletons.Prelude.Monoid
    Data.Singletons.Prelude.Num Data.Singletons.Prelude.Ord
    Data.Singletons.Prelude.Proxy Data.Singletons.Prelude.Semigroup
    Data.Singletons.Prelude.Show Data.Singletons.Prelude.Traversable
    Data.Singletons.Prelude.Tuple Data.Singletons.Prelude.Void
    Data.Singletons.ShowSing Data.Singletons.Sigma
    Data.Singletons.SuppressUnusedWarnings Data.Singletons.TH
    Data.Singletons.TH.Options Data.Singletons.TypeError
    Data.Singletons.TypeLits Data.Singletons.TypeRepTYPE

hidden-modules:
    Data.Singletons.Deriving.Infer Data.Singletons.Deriving.Bounded
    Data.Singletons.Deriving.Enum Data.Singletons.Deriving.Foldable
    Data.Singletons.Deriving.Functor Data.Singletons.Deriving.Ord
    Data.Singletons.Deriving.Show Data.Singletons.Deriving.Traversable
    Data.Singletons.Deriving.Util Data.Singletons.Internal
    Data.Singletons.Prelude.List.Internal
    Data.Singletons.Prelude.List.Internal.Disambiguation
    Data.Singletons.Prelude.Monad.Internal
    Data.Singletons.Prelude.Ord.Disambiguation
    Data.Singletons.Prelude.Semigroup.Internal
    Data.Singletons.Prelude.Semigroup.Internal.Disambiguation
    Data.Singletons.Promote Data.Singletons.Promote.Monad
    Data.Singletons.Promote.Eq Data.Singletons.Promote.Type
    Data.Singletons.Promote.Defun Data.Singletons.Util
    Data.Singletons.Partition Data.Singletons.Prelude.Instances
    Data.Singletons.Names Data.Singletons.Single.Monad
    Data.Singletons.Single.Type Data.Singletons.Single.Eq
    Data.Singletons.Single.Data Data.Singletons.Single.Defun
    Data.Singletons.Single.Fixity Data.Singletons.Single
    Data.Singletons.TypeLits.Internal Data.Singletons.Syntax

import-dirs:          /usr/lib/ghc-8.10.4/site-local/singletons-2.7
library-dirs:         /usr/lib/ghc-8.10.4/site-local/singletons-2.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/singletons-2.7
hs-libraries:         HSsingletons-2.7-KCTTIVBc6a7KNWaKwOeQIZ
depends:
    base-4.14.1.0 containers-0.6.2.1 ghc-boot-th-8.10.4 mtl-2.2.2
    pretty-1.1.3.6 syb-0.7.2.1-7IivvRpEqey3Ddb4vsqX1J
    template-haskell-2.16.0.0 text-1.2.4.1
    th-desugar-1.11-2qsVcvJox8ZKDnMumtRzXI transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-singletons2.7/html/singletons.haddock

haddock-html:         /usr/share/doc/haskell-singletons2.7/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
